Show index numbers in the NVRAM dump, similar to the PCI config space dump.

Signed-off-by: Uwe Hermann <uwe@hermann-uwe.de>
Acked-by: Jordan Crouse <jordan.crouse@amd.com>



git-svn-id: svn://svn.coreboot.org/coreboot/trunk@3246 2b7e53f0-3cfb-0310-b3e9-8179ed1497e1
diff --git a/payloads/coreinfo/Kconfig b/payloads/coreinfo/Kconfig
index 1b80db9..b0754de 100644
--- a/payloads/coreinfo/Kconfig
+++ b/payloads/coreinfo/Kconfig
@@ -62,7 +62,7 @@
 	bool "Enable the NVRAM dump module"
 	default y
 	help
-	  This option will increase the ELF file size by ca. 150 bytes.
+	  This option will increase the ELF file size by ca. 350 bytes.
 
 endmenu
 
diff --git a/payloads/coreinfo/nvram_module.c b/payloads/coreinfo/nvram_module.c
index d6af390..2c09f38 100644
--- a/payloads/coreinfo/nvram_module.c
+++ b/payloads/coreinfo/nvram_module.c
@@ -28,6 +28,19 @@
 {
 	int i, x = 0, y = 0;
 
+	/* Print vertical and horizontal index numbers. */
+	for (i = 0; i < 16; i++) {
+		mvwprintw(win, ((i < 8) ? 4 : 5) + i, 1, "%2.2X ", i);
+		mvwprintw(win, 2, 4 + (i * 3), "%2.2X ", i);
+	}
+
+	/* Print vertical and horizontal line. */
+	for (i = 0; i < 18; i++)
+		mvwaddch(win, 3 + i, 3, '\263');
+	for (i = 0; i < 48; i++)
+		mvwaddch(win, 3, 3 + i, (i == 0) ? '\332' : '\304');
+
+	/* Dump NVRAM contents. */
 	for (i = 1; i < 257; i++) {
 		mvwprintw(win, row + y, col + x, "%02x ", nvram_read(i - 1));
 		x += 3;
@@ -35,8 +48,8 @@
 			y++;	/* Start a newline after 16 bytes. */
 			x = 0;
 		}
-		if (i % 64 == 0) {
-			y++;	/* Add an empty line after 64 bytes. */
+		if (i % 128 == 0) {
+			y++;	/* Add an empty line after 128 bytes. */
 			x = 0;
 		}
 	}
@@ -45,7 +58,7 @@
 static int nvram_module_redraw(WINDOW *win)
 {
 	print_module_title(win, "NVRAM Dump");
-	dump_nvram(win, 2, 1);
+	dump_nvram(win, 4, 4);
 	return 0;
 }